What's new in version 1.3.1
===========================
Version available since November 29th 2023


New Features
------------
- GUI : plots are opened in matplotlib windows instead of directly in gui.
- GUI : vector inputs and outputs can be plotted.
- GUI : scrollbar added to the list of inputs and outputs of the gui.


Changes
-------
- Interpolation of pareto fronts is better with high number of points.
- compute_external and Print functions are moved from ode_tools.py to Tools.py
- gui2.py deleted and plot_sortedX function is moved to gui1.py


Contributors
------------
Lucas Agobert
Benoit Delinchant
